#include "StdAfx.h"
#include "Ring.h"
#include "math.h"

Ring::Ring(void):angle(0.0f),drawTriangle(true)
{
}

Ring::~Ring(void)
{
}


void Ring::Update(BYTE* keys){

	static float angle_inc=5.0f;

	if(keys[VK_SPACE] & 128){
		
		
	}
	
	angle+=angle_inc; // increase angle of rotation
}

void Ring::Init(void){
	////////////////////////////////////
	//your initialization code goes here
	////////////////////////////////////

	glEnable(GL_DEPTH_TEST); // check for depth
	
	glCullFace(GL_BACK); 
	glEnable(GL_CULL_FACE);
	
	glEnable(GL_LIGHTING); // switch on lighting
	glEnable(GL_LIGHT0); // switch on light0
	
	GLfloat light_color[]={1.0, 1.0, 1.0, 1.0};
	GLfloat light_position[]={0.0, 0.0, 10.0,0.0};


	glLightfv(GL_LIGHT0, GL_DIFFUSE, light_color); // set color of diffuse component
	glLightfv(GL_LIGHT0, GL_SPECULAR, light_color); // set color of specular component


	glLightfv(GL_LIGHT0, GL_POSITION, light_position);   // set position


	// set material to gold
	GLfloat mat_amb[]={0.24725f, 0.1995f, 0.0745f, 1.0f};
	GLfloat mat_diff[]={0.75164f, 0.60648f, 0.22648f, 1.0f};
	GLfloat mat_spec[]={0.628281f, 0.555802f, 0.366065f, 1.0f};
	GLfloat mat_shine[]={83.2f};

	glMaterialfv(GL_FRONT,GL_AMBIENT,mat_amb);
	glMaterialfv(GL_FRONT,GL_DIFFUSE,mat_diff);
	glMaterialfv(GL_FRONT,GL_SPECULAR,mat_spec);
	glMaterialfv(GL_FRONT,GL_SHININESS,mat_shine);

	glEnable(GL_NORMALIZE);



	// here is where all the work is done
	// this code could equally well load the data from file
	// generate array of points for the torus

	const double PI=3.141;
	const double  TWO_PI=PI*2.0, QUARTER_PI=PI/4.0, HALF_PI=PI/2.0;

	double R=1.0, r=0.2;
	
	int U,V;
	
	double u,v ;

	int t=0;
	int V1,U1;

	int vertex;
	for(U=0; U< U_STEPS;U++){
		for(V=0; V< V_STEPS;V++){
			u=TWO_PI*(double)U/(double)U_STEPS;
			v=TWO_PI*(double)V/(double)V_STEPS;

			vertex=U+ V*U_STEPS;
			// compute vertices of a torus
			vertices[vertex][0]=(GLfloat)((R+r*cos(u))*cos(v));
			vertices[vertex][1]=(GLfloat)(r*sin(u));
			vertices[vertex][2]=(GLfloat)((R+r*cos(u))*sin(v));


			// compute normal for each vertex
			normals[vertex][0]=vertices[vertex][0]-(GLfloat)(R*cos(v));
			normals[vertex][1]=vertices[vertex][1]-0;
			normals[vertex][2]=vertices[vertex][2]-(GLfloat)(R*sin(v));
		
			
			// create a mesh, the triaglearray contains indices to the vertices array
			// each group of3 indices specifies a triangle.
			V1=(V+1)%V_STEPS;
			U1=(U+1)%U_STEPS;


			
			triangles[t++]=vertex;
			triangles[t++]=U1+ V*U_STEPS;
			triangles[t++]=U+ V1*U_STEPS;

			triangles[t++]=U1+ V*U_STEPS;
			triangles[t++]=U1+ V1*U_STEPS;
			triangles[t++]=U+ V1*U_STEPS;
			
		}
	}

	// we want to use a vertex array
	glEnableClientState(GL_VERTEX_ARRAY);
	glVertexPointer(3,GL_FLOAT,0,(GLvoid*)vertices);

	// we want to use a normal array
	glEnableClientState(GL_NORMAL_ARRAY);
	glNormalPointer(GL_FLOAT,0,(GLvoid*)normals);

	return;//return success
}
void Ring::Draw(void){
	glPushMatrix();
	
	
	glRotatef(angle, 0.1f, 1.0f, 0.9f); //... then rotate everything around y-axis

	glDrawElements(GL_TRIANGLES, num_indices, GL_UNSIGNED_INT,triangles);
	glPopMatrix();
}
